@@ -1,12 +1,17 @@
 use std::fmt::Debug;
 use thiserror::Error;
 
+/// A type of error which can be returned whenever a lock is acquired.
+///
+/// A lock is poisoned whenever a thread panics while a lock is held.
 #[derive(Error, Debug, PartialEq, Eq, Hash, Clone, Copy)]
-pub enum PoisonError<K, G> {
-    #[error("The lock with the key `{key:?}` couldn't be acquired because another thread panicked while holding this lock")]
-    LockPoisoned { key: K, guard: G },
+#[error("The lock with the key `{key:?}` couldn't be acquired because another thread panicked while holding this lock")]
+pub struct PoisonError<K, G> {
+    pub key: K,
+    pub(super) guard: G,
 }
 
+/// Errors that can be thrown by [LockPool::unpoison](super::LockPool::unpoison).
 #[derive(Error, Debug, PartialEq, Eq, Hash, Clone, Copy)]
 pub enum UnpoisonError {
     #[error("Tried to unpoison a lock that wasn't poisoned")]
@@ -16,6 +21,7 @@ pub enum UnpoisonError {
     OtherThreadsBlockedOnMutex,
 }
 
+/// Errors that can be thrown by [LockPool::try_lock](super::LockPool::try_lock).
 #[derive(Error, Debug, PartialEq, Eq, Hash, Clone, Copy)]
 pub enum TryLockError<K, G> {
     #[error(transparent)]
